|PyPI|

ontobio - a python API for working with ontologies and associations
===================================================================

This module provides objects and utility methods for working with
ontologies and associations of entities (genes, variants, etc) to
ontology classes.

The ontologies and associations can either be local files or provided by
remote services (currently the OntoBee SPARQL service for ontologies and
a Monarch or GO Golr service for associations).

Documentation
=============

Documentation is on `readthedocs <https://ontobio.readthedocs.io>`__

Notebooks
=========

See the `Jupyter
Notebooks <http://nbviewer.jupyter.org/github/biolink/ontobio/tree/master/notebooks/>`__
for code examples

Mailing list
============

-  `biolink-api google
   group <https://groups.google.com/forum/#!forum/biolink-api>`__

.. |PyPI| image:: https://img.shields.io/pypi/v/ontobio.svg
   :target: https://pypi.python.org/pypi/ontobio
   
   
